#!/usr/bin/perl

# get command-line arguments, or die with a usage statement
my $usage = "combine_all_m8.pl summaryfile m8file outfile\n";
my $summaryfile = shift or die $usage;
my $m8file = shift or die $usage;
my $outfile = shift or die $usage;

open FILE, "< $summaryfile" or die "Can't open $summaryfile : $!";

# Declare a hash
my %good_names=();

#Little friendly output
print "Reading input summary file \'$summaryfile\':\n";
my $recs_processed = 0;

while(my $line = <FILE> ) {
    chomp($line);
    @values=split('\t',$line);

    # Make sure this line is showing a hit. Hit ID is in second column
    if($values[1] ne 'N_A'){
        # Save this name in hash.  Query name is in first column
        $good_names{$values[0]}=$values[1];
    }
    $recs_processed++;
}

print "Done.\n";

my $count = scalar keys %good_names;
print "$count queries found with hits.\n";

# Read m8 file (tab delimited)
open M8FILE, "< $m8file" or die "Can't open $m8file : $!";

# Write output file (tab delimited)
open OUTFILE, "> $outfile" or die "Can't open $outfile : $!";

print "Processing M8 file \'$m8file\':\n";

$recs_processed=0;
my $recs_printed=0;

# read each sequence in M8 file
while (my $line = <M8FILE>) {
    @values=split('\t',$line);

    # check hash for matching name
    if (exists($good_names{$values[0]})) {
        print OUTFILE $values[0] . "\t" . $values[1] . "\t" . $values[2] . "\t" . $values[3] . "\t" . $values[4] . "\t" . $values[5] . "\t" . $values[6] . "\t" . $values[7] . "\t" . $values[8] . "\t" . $values[9] . "\t" . $values[10] . "\t" . $values[11] .  "\n";
        $recs_printed++;
    }
    $recs_processed++;
}

print "Done.\n";
print "$recs_printed records printed to output file \'$outfile\'\n";
print "Process complete.\n";
exit;

